# ruff: noqa

from blackfish.plotting.spectrum import Spectrum, SpectrumType
from blackfish.plotting.templates import plotly_template
from blackfish.plotting.soc_absorption_spectrum_plot import soc_absorption_spectrum_plot
